@@ -26,8 +26,7 @@ use strict;
 #
 # @brief A parser for the disk_config files within FAI.
 #
-# @author Christian Kern, Michael Tautschnig, Sam Vilain, Andreas Schludei
-# @date Sun Jul 23 16:09:36 CEST 2006
+# @author Christian Kern, Michael Tautschnig, Sam Vilain, Andreas Schludei, Thomas Lange
 #
 ################################################################################
 
@@ -544,7 +543,7 @@ $FAI::Parser = Parse::RecDescent->new(
             $FAI::configs{RAID}{volumes}{$_}{preserve} = 2 foreach (split(",", $1));
           }
         }
-        | /^fstabkey:(device|label|uuid)/
+        | /^fstabkey:(device|label|uuid|partuuid|partlabel)/
         {
           # the information preferred for fstab device identifieres
           $FAI::configs{$FAI::device}{fstabkey} = $1;
@@ -558,7 +557,7 @@ $FAI::Parser = Parse::RecDescent->new(
           }
         }
 
-    btrfs_option: /^fstabkey:(device|label|uuid)/
+    btrfs_option: /^fstabkey:(device|label|uuid|partuuid|partlabel)/
         {
         $FAI::configs{$FAI::device}{fstabkey} = $1;
         }
@@ -703,10 +702,13 @@ $FAI::Parser = Parse::RecDescent->new(
           # this is a configuration for a virtual disk
           $FAI::configs{$FAI::device}{virtual} = 1;
         }
-        | /^fstabkey:(device|label|uuid)/
+        | /^fstabkey:(device|label|uuid|partuuid|partlabel)/
         {
           # the information preferred for fstab device identifieres
           $FAI::configs{$FAI::device}{fstabkey} = $1;
+          if ($1 eq 'partlabel' && $FAI::configs{$FAI::device}{disklabel} eq 'msdos') {
+            die "fstabkey:partlabel not allowed with msdos disk label\n";
+          }
         }
 	| /^vg:(\d+)/
 	{
@@ -884,6 +886,13 @@ $FAI::Parser = Parse::RecDescent->new(
           # partitioning it
           &FAI::init_part_config("raw");
         }
+        | m{^p=([^/,;\s=]*)\s+}
+        {
+          # gpt partition label
+          my $ptlabel = $1;
+          &FAI::init_part_config("primary");
+          $FAI::partition_pointer->{ptlabel} = $ptlabel if $ptlabel;
+        }
         | m{^([^/,\s\-]+)-([^/,\s\-]+)\s+}
         {
           # set $FAI::device to VG_$1
@@ -982,7 +991,7 @@ $FAI::Parser = Parse::RecDescent->new(
         }
         | <error: invalid partition size near "$text">
 
-    tmpfs_size: /^(RAM:(\d+%)|\d+[kKMGTPiB]*)\s+/
+    tmpfs_size: /^(RAM:(\d+%)|\d+[kKMGTPiB]*|-)\s+/
         {
           my $size;
 
@@ -990,6 +999,8 @@ $FAI::Parser = Parse::RecDescent->new(
           # A percentage is kept as is as tmpfs handles it
           if (defined($2)) {
             $size = $2;
+          } elsif ($1 eq '-') {
+            $size = '-';
           } else {
             $size = $1;
             $size .= "MiB" if ($size =~ /\d\s*$/);
